C  ****************************************************************************
C  *                                                                          *
C  *                    *****     STRINGLIB.SUBS     *****                    *
C  *                                                                          *
C  *    LIBRARY OF CHARACTER STRING MANIPULATION SUBROUTINES/FUNCTIONS:       *
C  *                                                                          *
C  *      STRING_BLANK    - BLANK OUT CHARACTER "STRING"                      *
C  *      STRING_CLEAR    - BLANK OUT CHARACTER "STRING"                      *
C  *      STRING_EQUAL    - DETERMINE IF TWO STRINGS ARE EQUAL.               *
C  *      STRING_LEN      - DETERMINE LENGTH OF "STRING"                      *
C  *      STRING_LOWER    - MAKE ALL CHARACTERS IN "STRING" LOWER CASE        *
C  *      STRING_REV      - REVERSE CHARACTERS IN "STRING"                    *
C  *      STRING_UPPER    - MAKE ALL CHARACTERS IN "STRING" UPPER CASE        *
C  ****************************************************************************
C
C
C  ****************************************************************************
C  *                                                                          *
C  *                 *****     SUBROUTINE STRING_BLANK     *****              *
C  *                                                                          *
C  *    BLANK OUT CHARACTERS IN "STRING"                                      *
C  *                                                                          *
C  *    MAY 1987  PURDUE UNIVERSITY VAX 11/750, T. BAKER                      *
C  ****************************************************************************
C
      SUBROUTINE STRING_BLANK (STRING)
C
      IMPLICIT NONE
C
      INTEGER*2      I, NCHARS, STRING_LEN
      CHARACTER *(*) STRING
C  ----------------------------------------------------------------------------
C
      NCHARS = STRING_LEN (STRING)
C
      DO I = 1,NCHARS
        STRING(I:I) = ' '
      ENDDO
C
       RETURN
      END

C  ****************************************************************************
C  *                                                                          *
C  *                 *****     SUBROUTINE STRING_CLEAR     *****              *
C  *                                                                          *
C  *    BLANK OUT CHARACTERS IN "STRING"                                      *
C  *                                                                          *
C  *    MAY 1987  PURDUE UNIVERSITY VAX 11/750, T. BAKER.                     *
C  *    LAST MODIFIED 16-MAY-1991 BY T. BAKER.                                *
C  ****************************************************************************
C
      SUBROUTINE STRING_CLEAR (STRING)
C
      IMPLICIT NONE
C
      INTEGER*2      I, NCHARS, STRING_LEN
      CHARACTER *(*) STRING
C  ----------------------------------------------------------------------------
C
      STRING = ' '
CCC      NCHARS = STRING_LEN(STRING)
C
CCC      DO I = 1,NCHARS
CCC        STRING(I:I) = ' '
CCC      ENDDO
C
       RETURN
      END

C  ****************************************************************************
C  *                                                                          *
C  *                  *****     FUNCTION STRING_EQUAL     *****               *
C  *                                                                          *
C  *    DETERMINE IF TWO CHARACTER STRINGS ARE IDENTICAL.                     *
C  *                                                                          *
C  *    APRIL 1992  PURDUE UNIVERSITY VAX 8550, D. MCKAY.                     *
C  *    LAST MODIFIED 10-APR-1992 BY T. BAKER.                                *
C  ****************************************************************************
C
      FUNCTION STRING_EQUAL (STR1, STR2)
C
      IMPLICIT NONE
C
      CHARACTER *(*) STR1, STR2
      INTEGER*4      POS, STRING_EQUAL
C  ----------------------------------------------------------------------------
C
      STRING_EQUAL = 0                  ! INITIALIZE RETURN VALUE...
C  *****************************************************
C  *    STRINGS MUST HAVE EQUAL LENGTHS TO BE EQUAL    *
C  *****************************************************
      IF(LEN(STR1) .NE. LEN(STR2)) THEN
        STRING_EQUAL = 1
        GO TO 100
      ENDIF
C  ***************************************
C  *    LOOP AND CHECK EACH CHARACTER    *
C  ***************************************
      DO POS = 1,LEN(STR1)
        IF (STR1(POS:POS) .NE. STR2(POS:POS)) STRING_EQUAL = 1
      ENDDO
  100      RETURN
      END

C  ****************************************************************************
C  *                                                                          *
C  *                  *****     FUNCTION STRING_LEN     *****                 *
C  *                                                                          *
C  *    DETERMINE THE NUMBER OF CHARACTERS IN "STRING" BY DISREGARDING        *
C  *     TRAILING BLANKS IN THE RIGHTHAND SIDE OF THE ARRAY                   *
C  *                                                                          *
C  *    AUGUST 1985  PURDUE UNIVERSITY VAX 11/750, T. BAKER                   *
C  ****************************************************************************
C
      INTEGER*2 FUNCTION STRING_LEN (STRING)
C
      IMPLICIT NONE
C
      INTEGER*2      I
      CHARACTER *(*) STRING
C  ----------------------------------------------------------------------------
C
      STRING_LEN = 0
C
      DO I = LEN(STRING),1,-1
        IF(STRING(I:I).GT.' ') THEN
          STRING_LEN = I
          RETURN
        ENDIF
      ENDDO
C
       RETURN
      END

C  **************************************************************
C  *                                                            *
C  *          *****     SUBROUTINE STRING_LOWER     *****       *
C  *                                                            *
C  *    MAKE ALL CHARACTERS IN "STRING" LOWER CASE              *
C  *                                                            *
C  *    OCTOBER 1986  PURDUE UNIVERSITY VAX 11/750, T. BAKER    *
C  **************************************************************
C
      SUBROUTINE STRING_LOWER (STRING)
C
      IMPLICIT NONE
C
      INTEGER*2     STRING_LEN, NUMCHR, ICHR, I
      CHARACTER*(*) STRING
C  ----------------------------------------------------------------------------
C
      NUMCHR = STRING_LEN (STRING)
C
      DO I = 1,NUMCHR
        ICHR = ICHAR(STRING(I:I))
        IF(ICHR.GT.64.AND.ICHR.LT.91) ICHR = ICHR+32
        STRING(I:I) = CHAR(ICHR)
      ENDDO
C
      RETURN
      END

C  ****************************************************************************
C  *                                                                          *
C  *                  *****     SUBROUTINE STRING_REV     *****               *
C  *                                                                          *
C  *    REVERSE THE ORDER OF CHARACTERS IN "STRING"                           *
C  *                                                                          *
C  *    AUGUST 1985  PURDUE UNIVERSITY VAX 11/750, T. BAKER                   *
C  ****************************************************************************
C
      SUBROUTINE STRING_REV (STRING)
C
      IMPLICIT NONE
C
      INTEGER*2 I, J
      CHARACTER S, STRING*(*)
C  ----------------------------------------------------------------------------
C
      J = LEN(STRING)
C
      DO I = 1,J/2
        S = STRING(I:I)
        STRING(I:I) = STRING(J:J)
        STRING(J:J) = S
        J = J-1
      ENDDO
C
      RETURN
      END

C  **************************************************************
C  *                                                            *
C  *          *****     SUBROUTINE STRING_UPPER     *****       *
C  *                                                            *
C  *    MAKE ALL CHARACTERS IN "STRING" UPPER CASE              *
C  *                                                            *
C  *    OCTOBER 1986  PURDUE UNIVERSITY VAX 11/750, T. BAKER    *
C  **************************************************************
C
      SUBROUTINE STRING_UPPER (STRING)
C
      IMPLICIT NONE
C
      INTEGER*2     STRING_LEN, NUMCHR, ICHR, I
      CHARACTER*(*) STRING
C  ----------------------------------------------------------------------------
C
      NUMCHR = STRING_LEN (STRING)
      DO I = 1,NUMCHR
        ICHR = ICHAR(STRING(I:I))
        IF(ICHR.GT.96.AND.ICHR.LT.123) ICHR = ICHR-32
        STRING(I:I) = CHAR(ICHR)
      ENDDO
C
      RETURN
      END
